These are the sequence files needed to run the manuscript worfklows.

When the sequence file is in the directory with the mzML files (or raw files), the pipeline will search for a file that matches the sample name with an mzml or raw extension. Alternatively, you can update the path to the location of the mzml files on your machine.

Where to get the data?

Bowen 2023 data can be downloaded from Metabolights (accession code MTBLS2746)
Ansone 2021 data can be downloaded from Metabolights (accession code MTBLS3852). 
Checkmate can be downloaded from Metabolomic Workbench (project ID: PR000828, study ID: ST001237).